=== modified file 'lib/lp/registry/browser/announcement.py'
--- lib/lp/registry/browser/announcement.py	2011-04-11 02:32:50 +0000
+++ lib/lp/registry/browser/announcement.py	2011-09-01 16:12:43 +0000
@@ -340,3 +340,5 @@
     @property
     def label(self):
         return self.context.title
+
+    page_title = label

=== added file 'lib/lp/registry/browser/tests/test_announcements.py'
--- lib/lp/registry/browser/tests/test_announcements.py	1970-01-01 00:00:00 +0000
+++ lib/lp/registry/browser/tests/test_announcements.py	2011-09-01 16:12:43 +0000
@@ -0,0 +1,47 @@
+# Copyright 2011 Canonical Ltd.  This software is licensed under the
+# GNU Affero General Public License version 3 (see the file LICENSE).
+
+"""Tests for +announcement views."""
+
+__metaclass__ = type
+
+from datetime import datetime
+
+from lxml import html
+from pytz import utc
+
+from canonical.testing.layers import LaunchpadFunctionalLayer
+from lp.testing import (
+    normalize_whitespace,
+    TestCaseWithFactory,
+    )
+from lp.testing.views import create_initialized_view
+
+
+class TestAnnouncement(TestCaseWithFactory):
+
+    layer = LaunchpadFunctionalLayer
+
+    def test_announcement_info(self):
+        product = self.factory.makeProduct(displayname=u"Foo")
+        announcer = self.factory.makePerson(displayname=u"Bar Baz")
+        announcement = product.announce(announcer, "Hello World")
+        view = create_initialized_view(announcement, "+index")
+        root = html.fromstring(view())
+        [reg_para] = root.cssselect("p.registered")
+        self.assertEqual(
+            "Written for Foo by Bar Baz",
+            normalize_whitespace(reg_para.text_content()))
+
+    def test_announcement_info_with_publication_date(self):
+        product = self.factory.makeProduct(displayname=u"Foo")
+        announcer = self.factory.makePerson(displayname=u"Bar Baz")
+        announced = datetime(2007, 01, 12, tzinfo=utc)
+        announcement = product.announce(
+            announcer, "Hello World", publication_date=announced)
+        view = create_initialized_view(announcement, "+index")
+        root = html.fromstring(view())
+        [reg_para] = root.cssselect("p.registered")
+        self.assertEqual(
+            "Written for Foo by Bar Baz on 2007-01-12",
+            normalize_whitespace(reg_para.text_content()))

=== modified file 'lib/lp/registry/templates/announcement-macros.pt'
--- lib/lp/registry/templates/announcement-macros.pt	2009-08-20 01:17:15 +0000
+++ lib/lp/registry/templates/announcement-macros.pt	2011-09-01 14:09:30 +0000
@@ -14,9 +14,6 @@
    tal:attributes="id id_string/fmt:css-id">
     <h2 tal:condition="show_title">
       <a tal:attributes="href string:${announcement/fmt:url}">
-        <tal:date tal:condition="announcement/date_announced">
-          <span tal:replace="announcement/date_announced/fmt:date"/>:
-        </tal:date>
         <tal:title content="announcement/title">News item title</tal:title>
       </a>
     </h2>
@@ -25,7 +22,11 @@
       Written for
       <tal:pillar replace="structure announcement/target/fmt:link" />
       by
-      <tal:registrant replace="structure announcement/registrant/fmt:link" />.
+      <tal:registrant replace="structure announcement/registrant/fmt:link" />
+      <tal:date tal:condition="announcement/date_announced">
+        on
+        <span tal:replace="announcement/date_announced/fmt:date" />
+      </tal:date>
     </p>
 
     <div tal:condition="announcement/summary"

